# frozen_string_literal: true

require 'nokogiri'
require 'mathml2latex/mathml_latex_service'

module Mathml2latex
  MATHML_NAMESPACE = 'http://www.w3.org/1998/Math/MathML'
  INSTUCTURE_LATEX_NS = 'http://instructure.com/latex'

  class Converter
    def initialize
      @service_object = Mathml2latex::MathmlLatexService.get_service_object
    end

    def to_latex(mathml)
      @service_object.to_latex(mathml)
    end

    def replace_with_latex(xml_doc)
      nodes = xml_doc.xpath('//mm:math', 'mm' => Mathml2latex::MATHML_NAMESPACE)
      nodes.each do |node|
        node.replace(<<~XML)
          <latex xmlns="#{Mathml2latex::INSTUCTURE_LATEX_NS}">#{@service_object.to_latex(node.dup.to_xml)}</latex>
        XML
      end
    end
  end
end
