# frozen_string_literal: true

require 'mathml2latex/xslt_functions'

module Mathml2latex
  INSTUCTURE_NAMESPACE = 'http://instructure.com/functions'

  class MathmlLatexService
    @xslt = nil

    def self.get_service_object # rubocop:disable Naming/AccessorMethodName
      setup_xslt
      new
    end

    def to_latex_from_file(mathml_file)
      mathml = File.open(mathml_file)
      to_latex(mathml)
    end

    def to_latex(mathml)
      doc = Nokogiri::XML(mathml)
      result = self.class.xslt.transform(doc)
      result.at_xpath('//text()').text
    end

    class << self
      attr_accessor :xslt

      private

      def initialized?
        !@xslt.nil?
      end

      def setup_xslt
        return if initialized?

        Nokogiri::XSLT.register Mathml2latex::INSTUCTURE_NAMESPACE, XsltFunctions
        path = File.join(File.dirname(__FILE__), 'xslt', 'mml2latex.xsl')
        @xslt = Nokogiri::XSLT(File.open(path))
      end
    end
  end
end
