# frozen_string_literal: true

# provide regex operations to xslt
# regex is not available to xslt 1.0
#
# This list is compiled from the following source:
# - https://github.com/transpect/mml2tex/blob/master/texmap/texmap.xml

module Mathml2latex
  SYMBOLS = {
    33 => '! ',                                                      # 21
    35 => '\# ',                                                     # 23
    36 => '\$ ',                                                     # 24
    37 => '\% ',                                                     # 25
    38 => '\& ',                                                     # 26
    39 => "\text{'}",                                                # 27
    40 => "\left(",                                                  # 28
    41 => "\right)",                                                 # 29
    58 => '\colon ',                                                 # 3a
    91 => "\left[",                                                  # 5b
    92 => '\backslash ',                                             # 5c
    93 => "\right]",                                                 # 5d
    94 => '\sphat ',                                                 # 5e
    95 => '\_ ',                                                     # 5f
    # 123 => '\{ ',                                                  # 7b
    123 => "\left\{",                                                # 7b
    # 125 => '\} ',                                                  # 7d
    125 => "\right\}",                                               # 7d
    126 => '\sim ',                                                  # 7e
    160 => '~ ',                                                     # a0
    162 => '\cent ',                                                 # a2
    163 => '\pounds ',                                               # a3
    165 => '\yen ',                                                  # a5
    172 => '\neg ',                                                  # ac
    174 => '\circledR ',                                             # ae
    175 => '\bar ',                                                  # af
    176 => '^{\circ} ',                                              # b0
    177 => '\pm ',                                                   # b1
    178 => '^{2} ',                                                  # b2
    179 => '^{3} ',                                                  # b3
    181 => '\mathrm{\mu} ',                                          # b5
    183 => '\cdot ',                                                 # b7
    185 => '^{1} ',                                                  # b9
    196 => '"A ',                                                    # c4
    214 => '"O ',                                                    # d6
    215 => '\times ',                                                # d7
    220 => '"U ',                                                    # dc
    223 => '{\ss} ',                                                 # df
    228 => '"a ',                                                    # e4
    240 => '\eth ',                                                  # f0
    246 => '"o ',                                                    # f6
    247 => '\div ',                                                  # f7
    252 => '"u ',                                                    # fc
    305 => '\imath ',                                                # 131
    402 => '\mathit{f}',                                             # 192
    567 => '\jmath ',                                                # 237
    603 => '\varepsilon ',                                           # 25b
    768 => '\grave ',                                                # 300
    769 => '\acute ',                                                # 301
    770 => '\hat ',                                                  # 302
    771 => '\tilde ',                                                # 303
    772 => '\bar ',                                                  # 304
    773 => '\overline ',                                             # 305
    774 => '\breve ',                                                # 306
    775 => '\dot ',                                                  # 307
    776 => '\ddot ',                                                 # 308
    778 => '\mathring ',                                             # 30a
    780 => '\check ',                                                # 30c
    816 => '\utilde ',                                               # 330
    817 => '\underbar ',                                             # 331
    818 => '\underline ',                                            # 332
    824 => '\not ',                                                  # 338
    913 => 'A ',                                                     # 391
    914 => 'B ',                                                     # 392
    915 => '\Gamma ',                                                # 393
    916 => '\Delta ',                                                # 394
    917 => 'E ',                                                     # 395
    918 => 'Z ',                                                     # 396
    919 => 'H ',                                                     # 397
    920 => '\Theta ',                                                # 398
    921 => 'I ',                                                     # 399
    922 => 'K ',                                                     # 39a
    923 => '\Lambda ',                                               # 39b
    924 => 'M ',                                                     # 39c
    925 => 'N ',                                                     # 39d
    926 => '\Xi ',                                                   # 39e
    927 => 'O ',                                                     # 39f
    928 => '\Pi ',                                                   # 3a0
    929 => 'P ',                                                     # 3a1
    931 => '\Sigma ',                                                # 3a3
    932 => 'T ',                                                     # 3a4
    933 => '\Upsilon ',                                              # 3a5
    934 => '\Phi ',                                                  # 3a6
    935 => 'X ',                                                     # 3a7
    936 => '\Psi ',                                                  # 3a8
    937 => '\Omega ',                                                # 3a9
    945 => '\alpha ',                                                # 3b1
    946 => '\beta ',                                                 # 3b2
    947 => '\gamma ',                                                # 3b3
    948 => '\delta ',                                                # 3b4
    949 => '\varepsilon ',                                           # 3b5
    950 => '\zeta ',                                                 # 3b6
    951 => '\eta ',                                                  # 3b7
    952 => '\theta ',                                                # 3b8
    953 => '\iota ',                                                 # 3b9
    954 => '\kappa ',                                                # 3ba
    955 => '\lambda ',                                               # 3bb
    956 => '\mu ',                                                   # 3bc
    957 => '\nu ',                                                   # 3bd
    958 => '\xi ',                                                   # 3be
    959 => 'o ',                                                     # 3bf
    960 => '\pi ',                                                   # 3c0
    961 => '\rho ',                                                  # 3c1
    962 => '\varsigma ',                                             # 3c2
    963 => '\sigma ',                                                # 3c3
    964 => '\tau ',                                                  # 3c4
    965 => '\upsilon ',                                              # 3c5
    966 => '\varphi ',                                               # 3c6
    967 => '\chi ',                                                  # 3c7
    968 => '\psi ',                                                  # 3c8
    969 => '\omega ',                                                # 3c9
    976 => '\upvarbeta ',                                            # 3d0
    977 => '\vartheta ',                                             # 3d1
    978 => '\Upsilon ',                                              # 3d2
    981 => '\phi ',                                                  # 3d5
    982 => '\varpi ',                                                # 3d6
    984 => '\Qoppa ',                                                # 3d8
    985 => '\qoppa ',                                                # 3d9
    986 => '\Stigma ',                                               # 3da
    987 => '\stigma ',                                               # 3db
    988 => '\Digamma ',                                              # 3dc
    989 => '\digamma ',                                              # 3dd
    990 => '\Koppa ',                                                # 3de
    991 => '\koppa ',                                                # 3df
    992 => '\Sampi ',                                                # 3e0
    993 => '\sampi ',                                                # 3e1
    1008 => '\varkappa ',                                            # 3f0
    1009 => '\varrho ',                                              # 3f1
    1013 => '\epsilon ',                                             # 3f5
    1014 => '\backepsilon ',                                         # 3f6
    8193 => '{\quad} ',                                              # 2001
    8194 => '{\enspace} ',                                           # 2002
    8195 => '{\quad} ',                                              # 2003
    8196 => '\, ',                                                   # 2004
    8197 => '\, ',                                                   # 2005
    8198 => '\, ',                                                   # 2006
    8199 => '\, ',                                                   # 2007
    8200 => '\, ',                                                   # 2008
    8201 => '\, ',                                                   # 2009
    8202 => '\, ',                                                   # 200a
    8203 => '\hspace{0pt} ',                                         # 200b
    8209 => '\hbox{-} ',                                             # 2011
    8210 => '- ',                                                    # 2012
    8211 => '\hbox{--} ',                                            # 2013
    8212 => '\hbox{---} ',                                           # 2014
    8213 => '\hbox{---} ',                                           # 2015
    8214 => '\| ',                                                   # 2016
    8216 => "' ",                                                    # 2018
    8217 => '` ',                                                    # 2019
    8218 => ', ',                                                    # 201a
    8219 => '` ',                                                    # 201b
    8220 => '`` ',                                                   # 201c
    8221 => "'' ",                                                   # 201d
    8222 => ',, ',                                                   # 201e
    8224 => '\dagger ',                                              # 2020
    8225 => '\ddagger ',                                             # 2021
    8226 => '\cdot ',                                                # 2022
    8227 => '\blacktriangleright ',                                  # 2023
    8228 => '\ldotp ',                                               # 2024
    8229 => '\ldotp\ldotp ',                                         # 2025
    8230 => '\ldots ',                                               # 2026
    8231 => '\cdot ',                                                # 2027
    8240 => '\permil ',                                              # 2030
    8242 => '\prime ',                                               # 2032
    8243 => '\second ',                                              # 2033
    8244 => "''' ",                                                  # 2034
    8245 => '\backprime ',                                           # 2035
    8256 => '\cat ',                                                 # 2040
    8279 => '\fourth ',                                              # 2057
    8287 => '\: ',                                                   # 205f
    8289 => '  ',                                                    # 2061
    8290 => '  ',                                                    # 2062
    8291 => '  ',                                                    # 2063
    8292 => '  ',                                                    # 2064
    8308 => '$^{4}$ ',                                               # 2074
    8309 => '$^{5}$ ',                                               # 2075
    8310 => '$^{6}$ ',                                               # 2076
    8311 => '$^{7}$ ',                                               # 2077
    8312 => '$^{8}$ ',                                               # 2078
    8313 => '$^{9}$ ',                                               # 2079
    8314 => '$^{+}$ ',                                               # 207a
    8315 => '$^{-}$ ',                                               # 207b
    8316 => '$^{=}$ ',                                               # 207c
    8317 => '$^{(}$ ',                                               # 207d
    8318 => '$^{)}$ ',                                               # 207e
    8319 => '$^{n}$ ',                                               # 207f
    8320 => '$_{0}$ ',                                               # 2080
    8321 => '$_{1}$ ',                                               # 2081
    8322 => '$_{2}$ ',                                               # 2082
    8323 => '$_{3}$ ',                                               # 2083
    8324 => '$_{4}$ ',                                               # 2084
    8325 => '$_{5}$ ',                                               # 2085
    8326 => '$_{6}$ ',                                               # 2086
    8327 => '$_{7}$ ',                                               # 2087
    8328 => '$_{8}$ ',                                               # 2088
    8329 => '$_{9}$ ',                                               # 2089
    8330 => '$_{+}$ ',                                               # 208a
    8331 => '$_{-}$ ',                                               # 208b
    8332 => '$_{=}$ ',                                               # 208c
    8333 => '$_{(}$ ',                                               # 208d
    8334 => '$_{)}$ ',                                               # 208e
    8336 => '$_{a}$ ',                                               # 2090
    8337 => '$_{e}$ ',                                               # 2091
    8338 => '$_{o}$ ',                                               # 2092
    8339 => '$_{x}$ ',                                               # 2093
    8340 => '$_{\text{\textschwa}}$ ',                               # 2094
    8341 => '$_{h}$ ',                                               # 2095
    8342 => '$_{k}$ ',                                               # 2096
    8343 => '$_{l}$ ',                                               # 2097
    8344 => '$_{m}$ ',                                               # 2098
    8345 => '$_{n}$ ',                                               # 2099
    8346 => '$_{p}$ ',                                               # 209a
    8347 => '$_{s}$ ',                                               # 209b
    8348 => '$_{t}$ ',                                               # 209c
    8364 => '\euro{}',                                               # 20ac
    8400 => '\lvec ',                                                # 20d0
    8401 => '\vec ',                                                 # 20d1
    8406 => '\LVec ',                                                # 20d6
    8407 => '\vec ',                                                 # 20d7
    8411 => '\dddot ',                                               # 20db
    8412 => '\ddddot ',                                              # 20dc
    8417 => '\overleftrightarrow ',                                  # 20e1
    8430 => '\underleftarrow ',                                      # 20ee
    8431 => '\underrightarrow ',                                     # 20ef
    # https://tex.stackexchange.com/questions/314082/when-to-use-hbar-or-hslash?utm_medium=organic&utm_source=google_rich_qa&utm_campaign=google_rich_qa
    8463 => '\hbar ',                                                # 210f
    # 8463 => '\hslash ',                                            # 210f
    8465 => '\Im ',                                                  # 2111
    8467 => '\ell ',                                                 # 2113
    8472 => '\wp ',                                                  # 2118
    8476 => '\Re ',                                                  # 211c
    8487 => '\mho ',                                                 # 2127
    8501 => '\aleph ',                                               # 2135
    8502 => '\beth ',                                                # 2136
    8503 => '\gimel ',                                               # 2137
    8504 => '\daleth ',                                              # 2138
    8517 => 'D',                                                     # 2145
    8518 => 'd',                                                     # 2146
    8519 => 'e',                                                     # 2147
    8520 => 'i',                                                     # 2148
    8592 => '\leftarrow ',                                           # 2190
    8593 => '\uparrow ',                                             # 2191
    8594 => '\rightarrow ',                                          # 2192
    8595 => '\downarrow ',                                           # 2193
    8596 => '\leftrightarrow ',                                      # 2194
    8597 => '\updownarrow ',                                         # 2195
    8598 => '\nwarrow ',                                             # 2196
    8599 => '\nearrow ',                                             # 2197
    8600 => '\searrow ',                                             # 2198
    8601 => '\swarrow ',                                             # 2199
    8602 => '\nleftarrow ',                                          # 219a
    8603 => '\nrightarrow ',                                         # 219b
    8606 => '\twoheadleftarrow ',                                    # 219e
    8608 => '\twoheadrightarrow ',                                   # 21a0
    8610 => '\leftarrowtail ',                                       # 21a2
    8611 => '\rightarrowtail ',                                      # 21a3
    8612 => '\mapsfrom ',                                            # 21a4
    8613 => '\MapsUp ',                                              # 21a5
    8614 => '\mapsto ',                                              # 21a6
    8615 => '\MapsDown ',                                            # 21a7
    8617 => '\hookleftarrow ',                                       # 21a9
    8618 => '\hookrightarrow ',                                      # 21aa
    8619 => '\looparrowleft ',                                       # 21ab
    8620 => '\looparrowright ',                                      # 21ac
    8621 => '\leftrightsquigarrow ',                                 # 21ad
    8622 => '\nleftrightarrow ',                                     # 21ae
    8623 => '\lightning ',                                           # 21af
    8624 => '\Lsh ',                                                 # 21b0
    8625 => '\Rsh ',                                                 # 21b1
    8626 => '\dlsh ',                                                # 21b2
    8627 => '\drsh ',                                                # 21b3
    8630 => '\curvearrowleft ',                                      # 21b6
    8631 => '\curvearrowright ',                                     # 21b7
    8634 => '\circlearrowleft ',                                     # 21ba
    8635 => '\circlearrowright ',                                    # 21bb
    8636 => '\leftharpoonup ',                                       # 21bc
    8637 => '\leftharpoondown ',                                     # 21bd
    8638 => '\upharpoonright ',                                      # 21be
    8639 => '\upharpoonleft ',                                       # 21bf
    8640 => '\rightharpoonup ',                                      # 21c0
    8641 => '\rightharpoondown ',                                    # 21c1
    8642 => '\downharpoonright ',                                    # 21c2
    8643 => '\downharpoonleft ',                                     # 21c3
    8644 => '\rightleftarrows ',                                     # 21c4
    8645 => '\updownarrows ',                                        # 21c5
    8646 => '\leftrightarrows ',                                     # 21c6
    8647 => '\leftleftarrows ',                                      # 21c7
    8648 => '\upuparrows ',                                          # 21c8
    8649 => '\rightrightarrows ',                                    # 21c9
    8650 => '\downdownarrows ',                                      # 21ca
    8651 => '\leftrightharpoons ',                                   # 21cb
    8652 => '\rightleftharpoons ',                                   # 21cc
    8653 => '\nLeftarrow ',                                          # 21cd
    8654 => '\nLeftrightarrow ',                                     # 21ce
    8655 => '\nRightarrow ',                                         # 21cf
    8656 => '\Leftarrow ',                                           # 21d0
    8657 => '\Uparrow ',                                             # 21d1
    8658 => '\Rightarrow ',                                          # 21d2
    8659 => '\Downarrow ',                                           # 21d3
    8660 => '\Leftrightarrow ',                                      # 21d4
    8661 => '\Updownarrow ',                                         # 21d5
    8662 => '\Nwarrow ',                                             # 21d6
    8663 => '\Nearrow ',                                             # 21d7
    8664 => '\Searrow ',                                             # 21d8
    8665 => '\Swarrow ',                                             # 21d9
    8666 => '\Lleftarrow ',                                          # 21da
    8667 => '\Rrightarrow ',                                         # 21db
    8668 => '\leftsquigarrow ',                                      # 21dc
    8669 => '\rightsquigarrow ',                                     # 21dd
    8672 => '\dashleftarrow ',                                       # 21e0
    8674 => '\dashrightarrow ',                                      # 21e2
    8676 => '\LeftArrowBar ',                                        # 21e4
    8677 => '\RightArrowBar ',                                       # 21e5
    8693 => '\downuparrows ',                                        # 21f5
    8696 => '\pfun ',                                                # 21f8
    8699 => '\ffun ',                                                # 21fb
    8701 => '\leftarrowtriangle ',                                   # 21fd
    8702 => '\rightarrowtriangle ',                                  # 21fe
    8703 => '\leftrightarrowtriangle ',                              # 21ff
    8704 => '\forall ',                                              # 2200
    8705 => '\complement ',                                          # 2201
    8706 => '\partial ',                                             # 2202
    8707 => '\exists ',                                              # 2203
    8708 => '\nexists ',                                             # 2204
    # https://tex.stackexchange.com/questions/22798/nice-looking-empty-set?utm_medium=organic&utm_source=google_rich_qa&utm_campaign=google_rich_qa
    # 8709 => '\emptyset ',                                          # 2205
    8709 => '\varnothing ',                                          # 2205
    8710 => '\triangle ',                                            # 2206
    8711 => '\nabla ',                                               # 2207
    8712 => '\in ',                                                  # 2208
    8713 => '\notin ',                                               # 2209
    8715 => '\ni ',                                                  # 220b
    8716 => '\not\ni ',                                              # 220c
    8719 => '\prod ',                                                # 220f
    8720 => '\coprod ',                                              # 2210
    8721 => '\sum ',                                                 # 2211
    8722 => '-',                                                     # 2212
    8723 => '\mp ',                                                  # 2213
    8724 => '\dotplus ',                                             # 2214
    8725 => '\slash ',                                               # 2215
    8726 => '\setminus ',                                            # 2216
    8727 => '\ast ',                                                 # 2217
    8728 => '\circ ',                                                # 2218
    8729 => '\bullet ',                                              # 2219
    8730 => '\surd ',                                                # 221a
    8733 => '\propto ',                                              # 221d
    8734 => '\infty ',                                               # 221e
    8735 => '\llcorner ',                                            # 221f
    8736 => '\angle ',                                               # 2220
    8737 => '\measuredangle ',                                       # 2221
    8738 => '\sphericalangle ',                                      # 2222
    8739 => '\mid ',                                                 # 2223
    # 8740 => '\nshortmid ',                                         # 2224
    8740 => '\nmid ',                                                # 2224
    8741 => '\parallel ',                                            # 2225
    # 8742 => '\nshortparallel ',                                    # 2226
    8742 => '\nparallel ',                                           # 2226
    8743 => '\wedge ',                                               # 2227
    8744 => '\vee ',                                                 # 2228
    8745 => '\cap ',                                                 # 2229
    8746 => '\cup ',                                                 # 222a
    8747 => '\int ',                                                 # 222b
    8748 => '\iint ',                                                # 222c
    8749 => '\iiint ',                                               # 222d
    8750 => '\oint ',                                                # 222e
    8751 => '\surfintegral ',                                        # 222f
    8752 => '\oiiint ',                                              # 2230
    8754 => '\varointclockwise ',                                    # 2232
    8755 => '\ointctrclockwise ',                                    # 2233
    8756 => '\therefore ',                                           # 2234
    8757 => '\because ',                                             # 2235
    8758 => ':',                                                     # 2236
    8759 => '\colon\colon ',                                         # 2237
    8760 => '\dot{-}',                                               # 2238
    8761 => '\eqcolon ',                                             # 2239
    8764 => '\sim ',                                                 # 223c
    8765 => '\backsim ',                                             # 223d
    8767 => '\AC ',                                                  # 223f
    8768 => '\wr ',                                                  # 2240
    8769 => '\nsim ',                                                # 2241
    8770 => '\eqsim ',                                               # 2242
    8771 => '\simeq ',                                               # 2243
    8772 => '\not\simeq ',                                           # 2244
    8773 => '\cong ',                                                # 2245
    8775 => '\ncong ',                                               # 2247
    8776 => '\approx ',                                              # 2248
    8777 => '\not\approx ',                                          # 2249
    8778 => '\approxeq ',                                            # 224a
    8781 => '\asymp ',                                               # 224d
    8782 => '\Bumpeq ',                                              # 224e
    8783 => '\bumpeq ',                                              # 224f
    8784 => '\doteq ',                                               # 2250
    8785 => '\doteqdot ',                                            # 2251
    8786 => '\fallingdotseq ',                                       # 2252
    8787 => '\risingdotseq ',                                        # 2253
    8790 => '\eqcirc ',                                              # 2256
    8791 => '\circeq ',                                              # 2257
    8792 => '\stackrel{\frown}{=}',                                  # 2258
    8793 => '\stackrel{\wedge}{=}',                                  # 2259
    8794 => '\stackrel{\vee}{=}',                                    # 225a
    8795 => '\stackrel{\star}{=}',                                   # 225b
    8796 => '\triangleq ',                                           # 225c
    8797 => '\stackrel{\scriptscriptstyle\mathrm{def}}{=}',          # 225d
    8798 => '\stackrel{\scriptscriptstyle\mathrm{m}}{=}',            # 225e
    8799 => '\stackrel{?}{=}',                                       # 225f
    8800 => '\ne ',                                                  # 2260
    8801 => '\equiv ',                                               # 2261
    8802 => '\not\equiv ',                                           # 2262
    8804 => '\le ',                                                  # 2264
    8805 => '\ge ',                                                  # 2265
    8806 => '\leqq ',                                                # 2266
    8807 => '\geqq ',                                                # 2267
    8808 => '\lneqq ',                                               # 2268
    8809 => '\gneqq ',                                               # 2269
    8810 => '\ll ',                                                  # 226a
    8811 => '\gg ',                                                  # 226b
    8812 => '\between ',                                             # 226c
    8813 => '\not\asymp ',                                           # 226d
    8814 => '\nless ',                                               # 226e
    8815 => '\ngtr ',                                                # 226f
    8816 => '\nleq ',                                                # 2270
    # 8816 => '\nleqq ',                                             # 2270
    8817 => '\ngeq ',                                                # 2271
    # 8817 => '\ngeqq ',                                             # 2271
    8818 => '\lesssim ',                                             # 2272
    8819 => '\gtrsim ',                                              # 2273
    8820 => '\not\lesssim ',                                         # 2274
    8821 => '\not\gtrsim ',                                          # 2275
    8822 => '\lessgtr ',                                             # 2276
    8823 => '\gtrless ',                                             # 2277
    8824 => '\not\lessgtr ',                                         # 2278
    8825 => '\not\gtrless ',                                         # 2279
    8826 => '\prec ',                                                # 227a
    8827 => '\succ ',                                                # 227b
    8828 => '\preccurlyeq ',                                         # 227c
    8829 => '\succcurlyeq ',                                         # 227d
    8830 => '\precsim ',                                             # 227e
    8831 => '\succsim ',                                             # 227f
    8832 => '\nprec ',                                               # 2280
    8833 => '\nsucc ',                                               # 2281
    8834 => '\subset ',                                              # 2282
    8835 => '\supset ',                                              # 2283
    8836 => '\not\subset ',                                          # 2284
    8837 => '\not\supset ',                                          # 2285
    8838 => '\subseteq ',                                            # 2286
    8839 => '\supseteq ',                                            # 2287
    8846 => '\uplus ',                                               # 228e
    8851 => '\sqcap ',                                               # 2293
    8852 => '\bigsqcup ',                                            # 2294
    8853 => '\oplus ',                                               # 2295
    8854 => '\ominus ',                                              # 2296
    8855 => '\otimes ',                                              # 2297
    8856 => '\oslash ',                                              # 2298
    8857 => '\odot ',                                                # 2299
    8863 => '\boxminus ',                                            # 229f
    8868 => '\top ',                                                 # 22a4
    8869 => '\perp ',                                                # 22a5
    8870 => '\vdash ',                                               # 22a6
    8871 => '\vDash ',                                               # 22a7
    8872 => '\models ',                                              # 22a8
    8874 => '\Vvdash ',                                              # 22aa
    8896 => '\bigwedge ',                                            # 22c0
    8897 => '\bigvee ',                                              # 22c1
    8898 => '\bigcap ',                                              # 22c2
    8899 => '\bigcup ',                                              # 22c3
    8900 => '\diamond ',                                             # 22c4
    8901 => '\cdot ',                                                # 22c5
    8902 => '\star ',                                                # 22c6
    8903 => '\divideontimes ',                                       # 22c7
    8904 => '\bowtie ',                                              # 22c8
    8909 => '\backsimeq ',                                           # 22cd
    8942 => '\vdots ',                                               # 22ee
    8943 => '\cdots ',                                               # 22ef
    8944 => '\adots ',                                               # 22f0
    8945 => '\ddots ',                                               # 22f1
    8960 => '\diameter ',                                            # 2300
    8968 => '\lceil ',                                               # 2308
    8969 => '\rceil ',                                               # 2309
    8970 => '\lfloor ',                                              # 230a
    8971 => '\rfloor ',                                              # 230b
    8976 => '\invneg ',                                              # 2310
    8977 => '\wasylozenge ',                                         # 2311
    8988 => '\ulcorner ',                                            # 231c
    8989 => '\urcorner ',                                            # 231d
    8990 => '\llcorner ',                                            # 231e
    8991 => '\lrcorner ',                                            # 231f
    8994 => '\frown ',                                               # 2322
    8995 => '\smile ',                                               # 2323
    9001 => '\langle ',                                              # 2329
    9002 => '\rangle ',                                              # 232a
    9017 => '\APLinv ',                                              # 2339
    9023 => '\notslash ',                                            # 233f
    9024 => '\notbackslash ',                                        # 2340
    9031 => '\APLleftarrowbox ',                                     # 2347
    9032 => '\APLrightarrowbox ',                                    # 2348
    9040 => '\APLuparrowbox ',                                       # 2350
    9047 => '\APLdownarrowbox ',                                     # 2357
    9053 => '\APLcomment ',                                          # 235d
    9054 => '\APLinput ',                                            # 235e
    9055 => '\APLlog ',                                              # 235f
    9082 => '\upalpha ',                                             # 237a
    9180 => '\overparen ',                                           # 23dc
    9181 => '\underparen ',                                          # 23dd
    9182 => '\overbrace ',                                           # 23de
    9183 => '\underbrace ',                                          # 23df
    9632 => '\blacksquare ',                                         # 25a0
    9633 => '\square ',                                              # 25a1
    9642 => '\blacksquare ',                                         # 25aa
    9651 => '\bigtriangleup ',                                       # 25b3
    9652 => '\blacktriangleup ',                                     # 25b4
    9653 => '\smalltriangleup ',                                     # 25b5
    9654 => '\RHD ',                                                 # 25b6
    9655 => '\rhd ',                                                 # 25b7
    9656 => '\blacktriangleright ',                                  # 25b8
    9657 => '\smalltriangleright ',                                  # 25b9
    9661 => '\bigtriangledown ',                                     # 25bd
    9662 => '\blacktriangledown ',                                   # 25be
    9663 => '\smalltriangledown ',                                   # 25bf
    9664 => '\LHD ',                                                 # 25c0
    9665 => '\lhd ',                                                 # 25c1
    9666 => '\blacktriangleleft ',                                   # 25c2
    9667 => '\smalltriangleleft ',                                   # 25c3
    9670 => '\Diamondblack ',                                        # 25c6
    9671 => '\Diamond ',                                             # 25c7
    9674 => '\lozenge ',                                             # 25ca
    9675 => '\Circle ',                                              # 25cb
    9679 => '\CIRCLE ',                                              # 25cf
    9680 => '\LEFTcircle ',                                          # 25d0
    9681 => '\RIGHTcircle ',                                         # 25d1
    9686 => '\LEFTCIRCLE ',                                          # 25d6
    9687 => '\RIGHTCIRCLE ',                                         # 25d7
    9707 => '\boxbar ',                                              # 25eb
    9723 => '\square ',                                              # 25fb
    9724 => '\blacksquare ',                                         # 25fc
    9733 => '\bigstar ',                                             # 2605
    9737 => '\Sun ',                                                 # 2609
    9742 => '\phone ',                                               # 260e
    9743 => '\phone ',                                               # 260f
    9744 => '\Square ',                                              # 2610
    9745 => '\CheckedBox ',                                          # 2611
    9746 => '\XBox ',                                                # 2612
    9749 => '\steaming ',                                            # 2615
    9758 => '\pointright ',                                          # 261e
    9760 => '\skull ',                                               # 2620
    9762 => '\radiation ',                                           # 2622
    9763 => '\biohazard ',                                           # 2623
    9775 => '\yinyang ',                                             # 262f
    9785 => '\frownie ',                                             # 2639
    9786 => '\smiley ',                                              # 263a
    9787 => '\blacksmiley ',                                         # 263b
    9788 => '\sun ',                                                 # 263c
    9789 => '\rightmoon ',                                           # 263d
    9790 => '\leftmoon ',                                            # 263e
    9791 => '\mercury ',                                             # 263f
    9792 => '\female ',                                              # 2640
    9793 => '\earth ',                                               # 2641
    9794 => '\male ',                                                # 2642
    9795 => '\jupiter ',                                             # 2643
    9796 => '\saturn ',                                              # 2644
    9797 => '\uranus ',                                              # 2645
    9798 => '\neptune ',                                             # 2646
    9799 => '\pluto ',                                               # 2647
    9800 => '\aries ',                                               # 2648
    9801 => '\taurus ',                                              # 2649
    9802 => '\gemini ',                                              # 264a
    9803 => '\cancer ',                                              # 264b
    9804 => '\leo ',                                                 # 264c
    9805 => '\virgo ',                                               # 264d
    9806 => '\libra ',                                               # 264e
    9807 => '\scorpio ',                                             # 264f
    9808 => '\sagittarius ',                                         # 2650
    9809 => '\capricornus ',                                         # 2651
    9810 => '\aquarius ',                                            # 2652
    9811 => '\pisces ',                                              # 2653
    9824 => '\spadesuit ',                                           # 2660
    9825 => '\heartsuit ',                                           # 2661
    9826 => '\diamondsuit ',                                         # 2662
    9827 => '\clubsuit ',                                            # 2663
    9828 => '\varspadesuit ',                                        # 2664
    9829 => '\varheartsuit ',                                        # 2665
    9830 => '\blacklozenge ',                                        # 2666
    9831 => '\varclubsuit ',                                         # 2667
    9833 => '\quarternote ',                                         # 2669
    9834 => '\eighthnote ',                                          # 266a
    9835 => '\twonotes ',                                            # 266b
    9836 => '\sixteenthnote ',                                       # 266c
    9837 => '\flat ',                                                # 266d
    9838 => '\natural ',                                             # 266e
    9839 => '\sharp ',                                               # 266f
    9851 => '\recycle ',                                             # 267b
    9875 => '\anchor ',                                              # 2693
    9876 => '\swords ',                                              # 2694
    9888 => '\warning ',                                             # 26a0
    9898 => '\medcirc ',                                             # 26aa
    9899 => '\medbullet ',                                           # 26ab
    9998 => '\pencil ',                                              # 270e
    10_003 => '\checkmark ',                                         # 2713
    10_007 => '\ballotx ',                                           # 2717
    10_016 => '\maltese ',                                           # 2720
    10_146 => '\arrowbullet ',                                       # 27a2
    10_178 => '\perp ',                                              # 27c2
    10_181 => '\Lbag ',                                              # 27c5
    10_182 => '\Rbag ',                                              # 27c6
    10_192 => '\Diamonddot ',                                        # 27d0
    10_204 => '\multimapinv ',                                       # 27dc
    10_214 => '\llbracket ',                                         # 27e6
    10_215 => '\rrbracket ',                                         # 27e7
    10_216 => '\langle ',                                            # 27e8
    10_217 => '\rangle ',                                            # 27e9
    10_218 => '\lang ',                                              # 27ea
    10_219 => '\rang ',                                              # 27eb
    10_222 => '\lgroup ',                                            # 27ee
    10_223 => '\rgroup ',                                            # 27ef
    10_229 => '\longleftarrow ',                                     # 27f5
    10_230 => '\longrightarrow ',                                    # 27f6
    10_231 => '\longleftrightarrow ',                                # 27f7
    10_232 => '\Longleftarrow ',                                     # 27f8
    10_233 => '\Longrightarrow ',                                    # 27f9
    10_234 => '\Longleftrightarrow ',                                # 27fa
    10_235 => '\longmapsfrom ',                                      # 27fb
    10_236 => '\longmapsto ',                                        # 27fc
    10_237 => '\Longmapsfrom ',                                      # 27fd
    10_238 => '\Longmapsto ',                                        # 27fe
    10_496 => '\psur ',                                              # 2900
    10_502 => '\Mapsfrom ',                                          # 2906
    10_503 => '\Mapsto ',                                            # 2907
    10_514 => '\UpArrowBar ',                                        # 2912
    10_515 => '\DownArrowBar ',                                      # 2913
    10_516 => '\pinj ',                                              # 2914
    10_517 => '\finj ',                                              # 2915
    10_518 => '\bij ',                                               # 2916
    10_547 => '\leadsto ',                                           # 2933
    10_570 => '\leftrightharpoon ',                                  # 294a
    10_571 => '\rightleftharpoon ',                                  # 294b
    10_574 => '\leftrightharpoonup ',                                # 294e
    10_575 => '\rightupdownharpoon ',                                # 294f
    10_576 => '\leftrightharpoondown ',                              # 2950
    10_577 => '\leftupdownharpoon ',                                 # 2951
    10_578 => '\LeftVectorBar ',                                     # 2952
    10_579 => '\RightVectorBar ',                                    # 2953
    10_580 => '\RightUpVectorBar ',                                  # 2954
    10_581 => '\RightDownVectorBar ',                                # 2955
    10_582 => '\DownLeftVectorBar ',                                 # 2956
    10_583 => '\DownRightVectorBar ',                                # 2957
    10_584 => '\LeftUpVectorBar ',                                   # 2958
    10_585 => '\LeftDownVectorBar ',                                 # 2959
    10_586 => '\LeftTeeVector ',                                     # 295a
    10_587 => '\RightTeeVector ',                                    # 295b
    10_588 => '\RightUpTeeVector ',                                  # 295c
    10_589 => '\RightDownTeeVector ',                                # 295d
    10_590 => '\DownLeftTeeVector ',                                 # 295e
    10_591 => '\DownRightTeeVector ',                                # 295f
    10_592 => '\LeftUpTeeVector ',                                   # 2960
    10_593 => '\LeftDownTeeVector ',                                 # 2961
    10_594 => '\leftleftharpoons ',                                  # 2962
    10_595 => '\upupharpoons ',                                      # 2963
    10_596 => '\rightrightharpoons ',                                # 2964
    10_597 => '\downdownharpoons ',                                  # 2965
    10_602 => '\leftbarharpoon ',                                    # 296a
    10_603 => '\barleftharpoon ',                                    # 296b
    10_604 => '\rightbarharpoon ',                                   # 296c
    10_605 => '\barrightharpoon ',                                   # 296d
    10_606 => '\updownharpoons ',                                    # 296e
    10_607 => '\downupharpoons ',                                    # 296f
    10_620 => '\strictfi ',                                          # 297c
    10_621 => '\strictif ',                                          # 297d
    10_624 => '\VERT ',                                              # 2980
    10_625 => '\spot ',                                              # 2981
    10_629 => '\Lparen ',                                            # 2985
    10_630 => '\Rparen ',                                            # 2986
    10_631 => '\limg ',                                              # 2987
    10_632 => '\rimg ',                                              # 2988
    10_633 => '\lblot ',                                             # 2989
    10_634 => '\rblot ',                                             # 298a
    10_680 => '\circledbslash ',                                     # 29b8
    10_688 => '\circledless ',                                       # 29c0
    10_689 => '\circledgtr ',                                        # 29c1
    10_692 => '\boxslash ',                                          # 29c4
    10_693 => '\boxbslash ',                                         # 29c5
    10_694 => '\boxast ',                                            # 29c6
    10_695 => '\boxcircle ',                                         # 29c7
    10_696 => '\boxbox ',                                            # 29c8
    10_703 => '\LeftTriangleBar ',                                   # 29cf
    10_704 => '\RightTriangleBar ',                                  # 29d0
    10_719 => '\multimapboth ',                                      # 29df
    10_731 => '\blacklozenge ',                                      # 29eb
    10_741 => '\setminus ',                                          # 29f5
    10_745 => '\zhide ',                                             # 29f9
    10_752 => '\bigodot ',                                           # 2a00
    10_753 => '\bigoplus ',                                          # 2a01
    10_754 => '\bigotimes ',                                         # 2a02
    10_756 => '\biguplus ',                                          # 2a04
    10_757 => '\bigsqcap ',                                          # 2a05
    10_758 => '\bigsqcup ',                                          # 2a06
    10_761 => '\varprod ',                                           # 2a09
    10_764 => '\iiiint ',                                            # 2a0c
    10_767 => '\fint ',                                              # 2a0f
    10_774 => '\sqint ',                                             # 2a16
    10_781 => '\Join ',                                              # 2a1d
    10_783 => '\zcmp ',                                              # 2a1f
    10_784 => '\zpipe ',                                             # 2a20
    10_785 => '\zproject ',                                          # 2a21
    10_814 => '\fcmp ',                                              # 2a3e
    10_815 => '\amalg ',                                             # 2a3f
    10_846 => '\doublebarwedge ',                                    # 2a5e
    10_852 => '\dsub ',                                              # 2a64
    10_853 => '\rsub ',                                              # 2a65
    10_868 => '\Coloneqq ',                                          # 2a74
    10_869 => '\Equal ',                                             # 2a75
    10_870 => '\Same ',                                              # 2a76
    10_877 => '\leqslant ',                                          # 2a7d
    10_878 => '\geqslant ',                                          # 2a7e
    10_885 => '\lessapprox ',                                        # 2a85
    10_886 => '\gtrapprox ',                                         # 2a86
    10_887 => '\lneq ',                                              # 2a87
    10_888 => '\gneq ',                                              # 2a88
    10_889 => '\lnapprox ',                                          # 2a89
    10_890 => '\gnapprox ',                                          # 2a8a
    10_891 => '\lesseqqgtr ',                                        # 2a8b
    10_892 => '\gtreqqless ',                                        # 2a8c
    10_901 => '\eqslantless ',                                       # 2a95
    10_902 => '\eqslantgtr ',                                        # 2a96
    10_913 => '\NestedLessLess ',                                    # 2aa1
    10_914 => '\NestedGreaterGreater ',                              # 2aa2
    10_918 => '\leftslice ',                                         # 2aa6
    10_919 => '\rightslice ',                                        # 2aa7
    10_927 => '\preceq ',                                            # 2aaf
    10_928 => '\succeq ',                                            # 2ab0
    10_931 => '\preceqq ',                                           # 2ab3
    10_932 => '\succeqq ',                                           # 2ab4
    10_935 => '\precapprox ',                                        # 2ab7
    10_936 => '\succapprox ',                                        # 2ab8
    10_937 => '\precnapprox ',                                       # 2ab9
    10_938 => '\succnapprox ',                                       # 2aba
    10_939 => '\llcurly ',                                           # 2abb
    10_940 => '\ggcurly ',                                           # 2abc
    10_949 => '\subseteqq ',                                         # 2ac5
    10_950 => '\supseteqq ',                                         # 2ac6
    10_955 => '\subsetneqq ',                                        # 2acb
    10_956 => '\supsetneqq ',                                        # 2acc
    10_986 => '\Top ',                                               # 2aea
    10_987 => '\Bot ',                                               # 2aeb
    10_996 => '\interleave ',                                        # 2af4
    11_004 => '\biginterleave ',                                     # 2afc
    11_005 => '\sslash ',                                            # 2afd
    11_006 => '\talloblong ',                                        # 2afe
    11_035 => '\blacksquare ',                                       # 2b1b
    11_036 => '\square ',                                            # 2b1c
    11_037 => '\blacksquare ',                                       # 2b1d
    11_047 => '\blacklozenge ',                                      # 2b27
    11_048 => '\lozenge ',                                           # 2b28
    119_808 => '\mathbf{A} ',                                        # 1d400
    119_809 => '\mathbf{B} ',                                        # 1d401
    119_810 => '\mathbf{C} ',                                        # 1d402
    119_811 => '\mathbf{D} ',                                        # 1d403
    119_812 => '\mathbf{E} ',                                        # 1d404
    119_813 => '\mathbf{F} ',                                        # 1d405
    119_814 => '\mathbf{G} ',                                        # 1d406
    119_815 => '\mathbf{H} ',                                        # 1d407
    119_816 => '\mathbf{I} ',                                        # 1d408
    119_817 => '\mathbf{J} ',                                        # 1d409
    119_818 => '\mathbf{K} ',                                        # 1d40a
    119_819 => '\mathbf{L} ',                                        # 1d40b
    119_820 => '\mathbf{M} ',                                        # 1d40c
    119_821 => '\mathbf{N} ',                                        # 1d40d
    119_822 => '\mathbf{O} ',                                        # 1d40e
    119_823 => '\mathbf{P} ',                                        # 1d40f
    119_824 => '\mathbf{Q} ',                                        # 1d410
    119_825 => '\mathbf{R} ',                                        # 1d411
    119_826 => '\mathbf{S} ',                                        # 1d412
    119_827 => '\mathbf{T} ',                                        # 1d413
    119_828 => '\mathbf{U} ',                                        # 1d414
    119_829 => '\mathbf{V} ',                                        # 1d415
    119_830 => '\mathbf{W} ',                                        # 1d416
    119_831 => '\mathbf{X} ',                                        # 1d417
    119_832 => '\mathbf{Y} ',                                        # 1d418
    119_833 => '\mathbf{Z} ',                                        # 1d419
    119_834 => '\mathbf{a} ',                                        # 1d41a
    119_835 => '\mathbf{b} ',                                        # 1d41b
    119_836 => '\mathbf{c} ',                                        # 1d41c
    119_837 => '\mathbf{d} ',                                        # 1d41d
    119_838 => '\mathbf{e} ',                                        # 1d41e
    119_839 => '\mathbf{f} ',                                        # 1d41f
    119_840 => '\mathbf{g} ',                                        # 1d420
    119_841 => '\mathbf{h} ',                                        # 1d421
    119_842 => '\mathbf{i} ',                                        # 1d422
    119_843 => '\mathbf{j} ',                                        # 1d423
    119_844 => '\mathbf{k} ',                                        # 1d424
    119_845 => '\mathbf{l} ',                                        # 1d425
    119_846 => '\mathbf{m} ',                                        # 1d426
    119_847 => '\mathbf{n} ',                                        # 1d427
    119_848 => '\mathbf{o} ',                                        # 1d428
    119_849 => '\mathbf{p} ',                                        # 1d429
    119_850 => '\mathbf{q} ',                                        # 1d42a
    119_851 => '\mathbf{r} ',                                        # 1d42b
    119_852 => '\mathbf{s} ',                                        # 1d42c
    119_853 => '\mathbf{t} ',                                        # 1d42d
    119_854 => '\mathbf{u} ',                                        # 1d42e
    119_855 => '\mathbf{v} ',                                        # 1d42f
    119_856 => '\mathbf{w} ',                                        # 1d430
    119_857 => '\mathbf{x} ',                                        # 1d431
    119_858 => '\mathbf{y} ',                                        # 1d432
    119_859 => '\mathbf{z} ',                                        # 1d433
    119_860 => 'A ',                                                 # 1d434
    119_861 => 'B ',                                                 # 1d435
    119_862 => 'C ',                                                 # 1d436
    119_863 => 'D ',                                                 # 1d437
    119_864 => 'E ',                                                 # 1d438
    119_865 => 'F ',                                                 # 1d439
    119_866 => 'G ',                                                 # 1d43a
    119_867 => 'H ',                                                 # 1d43b
    119_868 => 'I ',                                                 # 1d43c
    119_869 => 'J ',                                                 # 1d43d
    119_870 => 'K ',                                                 # 1d43e
    119_871 => 'L ',                                                 # 1d43f
    119_872 => 'M ',                                                 # 1d440
    119_873 => 'N ',                                                 # 1d441
    119_874 => 'O ',                                                 # 1d442
    119_875 => 'P ',                                                 # 1d443
    119_876 => 'Q ',                                                 # 1d444
    119_877 => 'R ',                                                 # 1d445
    119_878 => 'S ',                                                 # 1d446
    119_879 => 'T ',                                                 # 1d447
    119_880 => 'U ',                                                 # 1d448
    119_881 => 'V ',                                                 # 1d449
    119_882 => 'W ',                                                 # 1d44a
    119_883 => 'X ',                                                 # 1d44b
    119_884 => 'Y ',                                                 # 1d44c
    119_885 => 'Z ',                                                 # 1d44d
    119_886 => 'a ',                                                 # 1d44e
    119_887 => 'b ',                                                 # 1d44f
    119_888 => 'c ',                                                 # 1d450
    119_889 => 'd ',                                                 # 1d451
    119_890 => 'e ',                                                 # 1d452
    119_891 => 'f ',                                                 # 1d453
    119_892 => 'g ',                                                 # 1d454
    119_894 => 'i ',                                                 # 1d456
    119_895 => 'j ',                                                 # 1d457
    119_896 => 'k ',                                                 # 1d458
    119_897 => 'l ',                                                 # 1d459
    119_898 => 'm ',                                                 # 1d45a
    119_899 => 'n ',                                                 # 1d45b
    119_900 => 'o ',                                                 # 1d45c
    119_901 => 'p ',                                                 # 1d45d
    119_902 => 'q ',                                                 # 1d45e
    119_903 => 'r ',                                                 # 1d45f
    119_904 => 's ',                                                 # 1d460
    119_905 => 't ',                                                 # 1d461
    119_906 => 'u ',                                                 # 1d462
    119_907 => 'v ',                                                 # 1d463
    119_908 => 'w ',                                                 # 1d464
    119_909 => 'x ',                                                 # 1d465
    119_910 => 'y ',                                                 # 1d466
    119_911 => 'z ',                                                 # 1d467
    119_912 => '\mathbfit{A} ',                                      # 1d468
    119_913 => '\mathbfit{B} ',                                      # 1d469
    119_914 => '\mathbfit{C} ',                                      # 1d46a
    119_915 => '\mathbfit{D} ',                                      # 1d46b
    119_916 => '\mathbfit{E} ',                                      # 1d46c
    119_917 => '\mathbfit{F} ',                                      # 1d46d
    119_918 => '\mathbfit{G} ',                                      # 1d46e
    119_919 => '\mathbfit{H} ',                                      # 1d46f
    119_920 => '\mathbfit{I} ',                                      # 1d470
    119_921 => '\mathbfit{J} ',                                      # 1d471
    119_922 => '\mathbfit{K} ',                                      # 1d472
    119_923 => '\mathbfit{L} ',                                      # 1d473
    119_924 => '\mathbfit{M} ',                                      # 1d474
    119_925 => '\mathbfit{N} ',                                      # 1d475
    119_926 => '\mathbfit{O} ',                                      # 1d476
    119_927 => '\mathbfit{P} ',                                      # 1d477
    119_928 => '\mathbfit{Q} ',                                      # 1d478
    119_929 => '\mathbfit{R} ',                                      # 1d479
    119_930 => '\mathbfit{S} ',                                      # 1d47a
    119_931 => '\mathbfit{T} ',                                      # 1d47b
    119_932 => '\mathbfit{U} ',                                      # 1d47c
    119_933 => '\mathbfit{V} ',                                      # 1d47d
    119_934 => '\mathbfit{W} ',                                      # 1d47e
    119_935 => '\mathbfit{X} ',                                      # 1d47f
    119_936 => '\mathbfit{Y} ',                                      # 1d480
    119_937 => '\mathbfit{Z} ',                                      # 1d481
    119_938 => '\mathbfit{a} ',                                      # 1d482
    119_939 => '\mathbfit{b} ',                                      # 1d483
    119_940 => '\mathbfit{c} ',                                      # 1d484
    119_941 => '\mathbfit{d} ',                                      # 1d485
    119_942 => '\mathbfit{e} ',                                      # 1d486
    119_943 => '\mathbfit{f} ',                                      # 1d487
    119_944 => '\mathbfit{g} ',                                      # 1d488
    119_945 => '\mathbfit{h} ',                                      # 1d489
    119_946 => '\mathbfit{i} ',                                      # 1d48a
    119_947 => '\mathbfit{j} ',                                      # 1d48b
    119_948 => '\mathbfit{k} ',                                      # 1d48c
    119_949 => '\mathbfit{l} ',                                      # 1d48d
    119_950 => '\mathbfit{m} ',                                      # 1d48e
    119_951 => '\mathbfit{n} ',                                      # 1d48f
    119_952 => '\mathbfit{o} ',                                      # 1d490
    119_953 => '\mathbfit{p} ',                                      # 1d491
    119_954 => '\mathbfit{q} ',                                      # 1d492
    119_955 => '\mathbfit{r} ',                                      # 1d493
    119_956 => '\mathbfit{s} ',                                      # 1d494
    119_957 => '\mathbfit{t} ',                                      # 1d495
    119_958 => '\mathbfit{u} ',                                      # 1d496
    119_959 => '\mathbfit{v} ',                                      # 1d497
    119_960 => '\mathbfit{w} ',                                      # 1d498
    119_961 => '\mathbfit{x} ',                                      # 1d499
    119_962 => '\mathbfit{y} ',                                      # 1d49a
    119_963 => '\mathbfit{z} ',                                      # 1d49b
    119_964 => '\mathcal{A} ',                                       # 1d49c
    119_966 => '\mathcal{C} ',                                       # 1d49e
    119_967 => '\mathcal{D} ',                                       # 1d49f
    119_970 => '\mathcal{G} ',                                       # 1d4a2
    119_973 => '\mathcal{J} ',                                       # 1d4a5
    119_974 => '\mathcal{K} ',                                       # 1d4a6
    119_977 => '\mathcal{N} ',                                       # 1d4a9
    119_978 => '\mathcal{O} ',                                       # 1d4aa
    119_979 => '\mathcal{P} ',                                       # 1d4ab
    119_980 => '\mathcal{Q} ',                                       # 1d4ac
    119_982 => '\mathcal{S} ',                                       # 1d4ae
    119_983 => '\mathcal{T} ',                                       # 1d4af
    119_984 => '\mathcal{U} ',                                       # 1d4b0
    119_985 => '\mathcal{V} ',                                       # 1d4b1
    119_986 => '\mathcal{W} ',                                       # 1d4b2
    119_987 => '\mathcal{X} ',                                       # 1d4b3
    119_988 => '\mathcal{Y} ',                                       # 1d4b4
    119_989 => '\mathcal{Z} ',                                       # 1d4b5
    119_990 => '\mathcal{a} ',                                       # 1d4b6
    119_991 => '\mathcal{b} ',                                       # 1d4b7
    119_992 => '\mathcal{c} ',                                       # 1d4b8
    119_993 => '\mathcal{d} ',                                       # 1d4b9
    119_995 => '\mathcal{f} ',                                       # 1d4bb
    119_997 => '\mathcal{h} ',                                       # 1d4bd
    119_998 => '\mathcal{i} ',                                       # 1d4be
    119_999 => '\mathcal{j} ',                                       # 1d4bf
    120_000 => '\mathcal{k} ',                                       # 1d4c0
    120_001 => '\mathcal{l} ',                                       # 1d4c1
    120_002 => '\mathcal{m} ',                                       # 1d4c2
    120_003 => '\mathcal{n} ',                                       # 1d4c3
    120_005 => '\mathcal{p} ',                                       # 1d4c5
    120_006 => '\mathcal{q} ',                                       # 1d4c6
    120_007 => '\mathcal{r} ',                                       # 1d4c7
    120_008 => '\mathcal{s} ',                                       # 1d4c8
    120_009 => '\mathcal{t} ',                                       # 1d4c9
    120_010 => '\mathcal{u} ',                                       # 1d4ca
    120_011 => '\mathcal{v} ',                                       # 1d4cb
    120_012 => '\mathcal{w} ',                                       # 1d4cc
    120_013 => '\mathcal{x} ',                                       # 1d4cd
    120_014 => '\mathcal{y} ',                                       # 1d4ce
    120_015 => '\mathcal{z} ',                                       # 1d4cf
    120_068 => '\mathfrak{A} ',                                      # 1d504
    120_069 => '\mathfrak{B} ',                                      # 1d505
    120_071 => '\mathfrak{D} ',                                      # 1d507
    120_072 => '\mathfrak{E} ',                                      # 1d508
    120_073 => '\mathfrak{F} ',                                      # 1d509
    120_074 => '\mathfrak{G} ',                                      # 1d50a
    120_077 => '\mathfrak{J} ',                                      # 1d50d
    120_078 => '\mathfrak{K} ',                                      # 1d50e
    120_079 => '\mathfrak{L} ',                                      # 1d50f
    120_080 => '\mathfrak{M} ',                                      # 1d510
    120_081 => '\mathfrak{N} ',                                      # 1d511
    120_082 => '\mathfrak{O} ',                                      # 1d512
    120_083 => '\mathfrak{P} ',                                      # 1d513
    120_084 => '\mathfrak{Q} ',                                      # 1d514
    120_086 => '\mathfrak{S} ',                                      # 1d516
    120_087 => '\mathfrak{T} ',                                      # 1d517
    120_088 => '\mathfrak{U} ',                                      # 1d518
    120_089 => '\mathfrak{V} ',                                      # 1d519
    120_090 => '\mathfrak{W} ',                                      # 1d51a
    120_091 => '\mathfrak{X} ',                                      # 1d51b
    120_092 => '\mathfrak{Y} ',                                      # 1d51c
    120_094 => '\mathfrak{a} ',                                      # 1d51e
    120_095 => '\mathfrak{b} ',                                      # 1d51f
    120_096 => '\mathfrak{c} ',                                      # 1d520
    120_097 => '\mathfrak{d} ',                                      # 1d521
    120_098 => '\mathfrak{e} ',                                      # 1d522
    120_099 => '\mathfrak{f} ',                                      # 1d523
    120_100 => '\mathfrak{g} ',                                      # 1d524
    120_101 => '\mathfrak{h} ',                                      # 1d525
    120_102 => '\mathfrak{i} ',                                      # 1d526
    120_103 => '\mathfrak{j} ',                                      # 1d527
    120_104 => '\mathfrak{k} ',                                      # 1d528
    120_105 => '\mathfrak{l} ',                                      # 1d529
    120_106 => '\mathfrak{m} ',                                      # 1d52a
    120_107 => '\mathfrak{n} ',                                      # 1d52b
    120_108 => '\mathfrak{o} ',                                      # 1d52c
    120_109 => '\mathfrak{p} ',                                      # 1d52d
    120_110 => '\mathfrak{q} ',                                      # 1d52e
    120_111 => '\mathfrak{r} ',                                      # 1d52f
    120_112 => '\mathfrak{s} ',                                      # 1d530
    120_113 => '\mathfrak{t} ',                                      # 1d531
    120_114 => '\mathfrak{u} ',                                      # 1d532
    120_115 => '\mathfrak{v} ',                                      # 1d533
    120_116 => '\mathfrak{w} ',                                      # 1d534
    120_117 => '\mathfrak{x} ',                                      # 1d535
    120_118 => '\mathfrak{y} ',                                      # 1d536
    120_119 => '\mathfrak{z} ',                                      # 1d537
    120_120 => '\mathbb{A} ',                                        # 1d538
    120_121 => '\mathbb{B} ',                                        # 1d539
    120_123 => '\mathbb{D} ',                                        # 1d53b
    120_124 => '\mathbb{E} ',                                        # 1d53c
    120_125 => '\mathbb{F} ',                                        # 1d53d
    120_126 => '\mathbb{G} ',                                        # 1d53e
    120_128 => '\mathbb{I} ',                                        # 1d540
    120_129 => '\mathbb{J} ',                                        # 1d541
    120_130 => '\mathbb{K} ',                                        # 1d542
    120_131 => '\mathbb{L} ',                                        # 1d543
    120_132 => '\mathbb{M} ',                                        # 1d544
    120_134 => '\mathbb{O} ',                                        # 1d546
    120_138 => '\mathbb{S} ',                                        # 1d54a
    120_139 => '\mathbb{T} ',                                        # 1d54b
    120_140 => '\mathbb{U} ',                                        # 1d54c
    120_141 => '\mathbb{V} ',                                        # 1d54d
    120_142 => '\mathbb{W} ',                                        # 1d54e
    120_143 => '\mathbb{X} ',                                        # 1d54f
    120_144 => '\mathbb{Y} ',                                        # 1d550
    120_146 => '\mathbb{a} ',                                        # 1d552
    120_147 => '\mathbb{b} ',                                        # 1d553
    120_148 => '\mathbb{c} ',                                        # 1d554
    120_149 => '\mathbb{d} ',                                        # 1d555
    120_150 => '\mathbb{e} ',                                        # 1d556
    120_151 => '\mathbb{f} ',                                        # 1d557
    120_152 => '\mathbb{g} ',                                        # 1d558
    120_153 => '\mathbb{h} ',                                        # 1d559
    120_154 => '\mathbb{i} ',                                        # 1d55a
    120_155 => '\mathbb{j} ',                                        # 1d55b
    120_156 => '\mathbb{k} ',                                        # 1d55c
    120_157 => '\mathbb{l} ',                                        # 1d55d
    120_158 => '\mathbb{m} ',                                        # 1d55e
    120_159 => '\mathbb{n} ',                                        # 1d55f
    120_160 => '\mathbb{o} ',                                        # 1d560
    120_161 => '\mathbb{p} ',                                        # 1d561
    120_162 => '\mathbb{q} ',                                        # 1d562
    120_163 => '\mathbb{r} ',                                        # 1d563
    120_164 => '\mathbb{s} ',                                        # 1d564
    120_165 => '\mathbb{t} ',                                        # 1d565
    120_166 => '\mathbb{u} ',                                        # 1d566
    120_167 => '\mathbb{v} ',                                        # 1d567
    120_168 => '\mathbb{w} ',                                        # 1d568
    120_169 => '\mathbb{x} ',                                        # 1d569
    120_170 => '\mathbb{y} ',                                        # 1d56a
    120_171 => '\mathbb{z} ',                                        # 1d56b
    120_224 => '\mathsf{A} ',                                        # 1d5a0
    120_225 => '\mathsf{B} ',                                        # 1d5a1
    120_226 => '\mathsf{C} ',                                        # 1d5a2
    120_227 => '\mathsf{D} ',                                        # 1d5a3
    120_228 => '\mathsf{E} ',                                        # 1d5a4
    120_229 => '\mathsf{F} ',                                        # 1d5a5
    120_230 => '\mathsf{G} ',                                        # 1d5a6
    120_231 => '\mathsf{H} ',                                        # 1d5a7
    120_232 => '\mathsf{I} ',                                        # 1d5a8
    120_233 => '\mathsf{J} ',                                        # 1d5a9
    120_234 => '\mathsf{K} ',                                        # 1d5aa
    120_235 => '\mathsf{L} ',                                        # 1d5ab
    120_236 => '\mathsf{M} ',                                        # 1d5ac
    120_237 => '\mathsf{N} ',                                        # 1d5ad
    120_238 => '\mathsf{O} ',                                        # 1d5ae
    120_239 => '\mathsf{P} ',                                        # 1d5af
    120_240 => '\mathsf{Q} ',                                        # 1d5b0
    120_241 => '\mathsf{R} ',                                        # 1d5b1
    120_242 => '\mathsf{S} ',                                        # 1d5b2
    120_243 => '\mathsf{T} ',                                        # 1d5b3
    120_244 => '\mathsf{U} ',                                        # 1d5b4
    120_245 => '\mathsf{V} ',                                        # 1d5b5
    120_246 => '\mathsf{W} ',                                        # 1d5b6
    120_247 => '\mathsf{X} ',                                        # 1d5b7
    120_248 => '\mathsf{Y} ',                                        # 1d5b8
    120_249 => '\mathsf{Z} ',                                        # 1d5b9
    120_250 => '\mathsf{a} ',                                        # 1d5ba
    120_251 => '\mathsf{b} ',                                        # 1d5bb
    120_252 => '\mathsf{c} ',                                        # 1d5bc
    120_253 => '\mathsf{d} ',                                        # 1d5bd
    120_254 => '\mathsf{e} ',                                        # 1d5be
    120_255 => '\mathsf{f} ',                                        # 1d5bf
    120_256 => '\mathsf{g} ',                                        # 1d5c0
    120_257 => '\mathsf{h} ',                                        # 1d5c1
    120_258 => '\mathsf{i} ',                                        # 1d5c2
    120_259 => '\mathsf{j} ',                                        # 1d5c3
    120_260 => '\mathsf{k} ',                                        # 1d5c4
    120_261 => '\mathsf{l} ',                                        # 1d5c5
    120_262 => '\mathsf{m} ',                                        # 1d5c6
    120_263 => '\mathsf{n} ',                                        # 1d5c7
    120_264 => '\mathsf{o} ',                                        # 1d5c8
    120_265 => '\mathsf{p} ',                                        # 1d5c9
    120_266 => '\mathsf{q} ',                                        # 1d5ca
    120_267 => '\mathsf{r} ',                                        # 1d5cb
    120_268 => '\mathsf{s} ',                                        # 1d5cc
    120_269 => '\mathsf{t} ',                                        # 1d5cd
    120_270 => '\mathsf{u} ',                                        # 1d5ce
    120_271 => '\mathsf{v} ',                                        # 1d5cf
    120_272 => '\mathsf{w} ',                                        # 1d5d0
    120_273 => '\mathsf{x} ',                                        # 1d5d1
    120_274 => '\mathsf{y} ',                                        # 1d5d2
    120_275 => '\mathsf{z} ',                                        # 1d5d3
    120_276 => '\mathsfbf{A} ',                                      # 1d5d4
    120_277 => '\mathsfbf{B} ',                                      # 1d5d5
    120_278 => '\mathsfbf{C} ',                                      # 1d5d6
    120_279 => '\mathsfbf{D} ',                                      # 1d5d7
    120_280 => '\mathsfbf{E} ',                                      # 1d5d8
    120_281 => '\mathsfbf{F} ',                                      # 1d5d9
    120_282 => '\mathsfbf{G} ',                                      # 1d5da
    120_283 => '\mathsfbf{H} ',                                      # 1d5db
    120_284 => '\mathsfbf{I} ',                                      # 1d5dc
    120_285 => '\mathsfbf{J} ',                                      # 1d5dd
    120_286 => '\mathsfbf{K} ',                                      # 1d5de
    120_287 => '\mathsfbf{L} ',                                      # 1d5df
    120_288 => '\mathsfbf{M} ',                                      # 1d5e0
    120_289 => '\mathsfbf{N} ',                                      # 1d5e1
    120_290 => '\mathsfbf{O} ',                                      # 1d5e2
    120_291 => '\mathsfbf{P} ',                                      # 1d5e3
    120_292 => '\mathsfbf{Q} ',                                      # 1d5e4
    120_293 => '\mathsfbf{R} ',                                      # 1d5e5
    120_294 => '\mathsfbf{S} ',                                      # 1d5e6
    120_295 => '\mathsfbf{T} ',                                      # 1d5e7
    120_296 => '\mathsfbf{U} ',                                      # 1d5e8
    120_297 => '\mathsfbf{V} ',                                      # 1d5e9
    120_298 => '\mathsfbf{W} ',                                      # 1d5ea
    120_299 => '\mathsfbf{X} ',                                      # 1d5eb
    120_300 => '\mathsfbf{Y} ',                                      # 1d5ec
    120_301 => '\mathsfbf{Z} ',                                      # 1d5ed
    120_302 => '\mathsfbf{a} ',                                      # 1d5ee
    120_303 => '\mathsfbf{b} ',                                      # 1d5ef
    120_304 => '\mathsfbf{c} ',                                      # 1d5f0
    120_305 => '\mathsfbf{d} ',                                      # 1d5f1
    120_306 => '\mathsfbf{e} ',                                      # 1d5f2
    120_307 => '\mathsfbf{f} ',                                      # 1d5f3
    120_308 => '\mathsfbf{g} ',                                      # 1d5f4
    120_309 => '\mathsfbf{h} ',                                      # 1d5f5
    120_310 => '\mathsfbf{i} ',                                      # 1d5f6
    120_311 => '\mathsfbf{j} ',                                      # 1d5f7
    120_312 => '\mathsfbf{k} ',                                      # 1d5f8
    120_313 => '\mathsfbf{l} ',                                      # 1d5f9
    120_314 => '\mathsfbf{m} ',                                      # 1d5fa
    120_315 => '\mathsfbf{n} ',                                      # 1d5fb
    120_316 => '\mathsfbf{o} ',                                      # 1d5fc
    120_317 => '\mathsfbf{p} ',                                      # 1d5fd
    120_318 => '\mathsfbf{q} ',                                      # 1d5fe
    120_319 => '\mathsfbf{r} ',                                      # 1d5ff
    120_320 => '\mathsfbf{s} ',                                      # 1d600
    120_321 => '\mathsfbf{t} ',                                      # 1d601
    120_322 => '\mathsfbf{u} ',                                      # 1d602
    120_323 => '\mathsfbf{v} ',                                      # 1d603
    120_324 => '\mathsfbf{w} ',                                      # 1d604
    120_325 => '\mathsfbf{x} ',                                      # 1d605
    120_326 => '\mathsfbf{y} ',                                      # 1d606
    120_327 => '\mathsfbf{z} ',                                      # 1d607
    120_328 => '\mathsfit{A} ',                                      # 1d608
    120_329 => '\mathsfit{B} ',                                      # 1d609
    120_330 => '\mathsfit{C} ',                                      # 1d60a
    120_331 => '\mathsfit{D} ',                                      # 1d60b
    120_332 => '\mathsfit{E} ',                                      # 1d60c
    120_333 => '\mathsfit{F} ',                                      # 1d60d
    120_334 => '\mathsfit{G} ',                                      # 1d60e
    120_335 => '\mathsfit{H} ',                                      # 1d60f
    120_336 => '\mathsfit{I} ',                                      # 1d610
    120_337 => '\mathsfit{J} ',                                      # 1d611
    120_338 => '\mathsfit{K} ',                                      # 1d612
    120_339 => '\mathsfit{L} ',                                      # 1d613
    120_340 => '\mathsfit{M} ',                                      # 1d614
    120_341 => '\mathsfit{N} ',                                      # 1d615
    120_342 => '\mathsfit{O} ',                                      # 1d616
    120_343 => '\mathsfit{P} ',                                      # 1d617
    120_344 => '\mathsfit{Q} ',                                      # 1d618
    120_345 => '\mathsfit{R} ',                                      # 1d619
    120_346 => '\mathsfit{S} ',                                      # 1d61a
    120_347 => '\mathsfit{T} ',                                      # 1d61b
    120_348 => '\mathsfit{U} ',                                      # 1d61c
    120_349 => '\mathsfit{V} ',                                      # 1d61d
    120_350 => '\mathsfit{W} ',                                      # 1d61e
    120_351 => '\mathsfit{X} ',                                      # 1d61f
    120_352 => '\mathsfit{Y} ',                                      # 1d620
    120_353 => '\mathsfit{Z} ',                                      # 1d621
    120_354 => '\mathsfit{a} ',                                      # 1d622
    120_355 => '\mathsfit{b} ',                                      # 1d623
    120_356 => '\mathsfit{c} ',                                      # 1d624
    120_357 => '\mathsfit{d} ',                                      # 1d625
    120_358 => '\mathsfit{e} ',                                      # 1d626
    120_359 => '\mathsfit{f} ',                                      # 1d627
    120_360 => '\mathsfit{g} ',                                      # 1d628
    120_361 => '\mathsfit{h} ',                                      # 1d629
    120_362 => '\mathsfit{i} ',                                      # 1d62a
    120_363 => '\mathsfit{j} ',                                      # 1d62b
    120_364 => '\mathsfit{k} ',                                      # 1d62c
    120_365 => '\mathsfit{l} ',                                      # 1d62d
    120_366 => '\mathsfit{m} ',                                      # 1d62e
    120_367 => '\mathsfit{n} ',                                      # 1d62f
    120_368 => '\mathsfit{o} ',                                      # 1d630
    120_369 => '\mathsfit{p} ',                                      # 1d631
    120_370 => '\mathsfit{q} ',                                      # 1d632
    120_371 => '\mathsfit{r} ',                                      # 1d633
    120_372 => '\mathsfit{s} ',                                      # 1d634
    120_373 => '\mathsfit{t} ',                                      # 1d635
    120_374 => '\mathsfit{u} ',                                      # 1d636
    120_375 => '\mathsfit{v} ',                                      # 1d637
    120_376 => '\mathsfit{w} ',                                      # 1d638
    120_377 => '\mathsfit{x} ',                                      # 1d639
    120_378 => '\mathsfit{y} ',                                      # 1d63a
    120_379 => '\mathsfit{z} ',                                      # 1d63b
    120_380 => '\mathsfbfit{A} ',                                    # 1d63c
    120_381 => '\mathsfbfit{B} ',                                    # 1d63d
    120_382 => '\mathsfbfit{C} ',                                    # 1d63e
    120_383 => '\mathsfbfit{D} ',                                    # 1d63f
    120_384 => '\mathsfbfit{E} ',                                    # 1d640
    120_385 => '\mathsfbfit{F} ',                                    # 1d641
    120_386 => '\mathsfbfit{G} ',                                    # 1d642
    120_387 => '\mathsfbfit{H} ',                                    # 1d643
    120_388 => '\mathsfbfit{I} ',                                    # 1d644
    120_389 => '\mathsfbfit{J} ',                                    # 1d645
    120_390 => '\mathsfbfit{K} ',                                    # 1d646
    120_391 => '\mathsfbfit{L} ',                                    # 1d647
    120_392 => '\mathsfbfit{M} ',                                    # 1d648
    120_393 => '\mathsfbfit{N} ',                                    # 1d649
    120_394 => '\mathsfbfit{O} ',                                    # 1d64a
    120_395 => '\mathsfbfit{P} ',                                    # 1d64b
    120_396 => '\mathsfbfit{Q} ',                                    # 1d64c
    120_397 => '\mathsfbfit{R} ',                                    # 1d64d
    120_398 => '\mathsfbfit{S} ',                                    # 1d64e
    120_399 => '\mathsfbfit{T} ',                                    # 1d64f
    120_400 => '\mathsfbfit{U} ',                                    # 1d650
    120_401 => '\mathsfbfit{V} ',                                    # 1d651
    120_402 => '\mathsfbfit{W} ',                                    # 1d652
    120_403 => '\mathsfbfit{X} ',                                    # 1d653
    120_404 => '\mathsfbfit{Y} ',                                    # 1d654
    120_405 => '\mathsfbfit{Z} ',                                    # 1d655
    120_406 => '\mathsfbfit{a} ',                                    # 1d656
    120_407 => '\mathsfbfit{b} ',                                    # 1d657
    120_408 => '\mathsfbfit{c} ',                                    # 1d658
    120_409 => '\mathsfbfit{d} ',                                    # 1d659
    120_410 => '\mathsfbfit{e} ',                                    # 1d65a
    120_411 => '\mathsfbfit{f} ',                                    # 1d65b
    120_412 => '\mathsfbfit{g} ',                                    # 1d65c
    120_413 => '\mathsfbfit{h} ',                                    # 1d65d
    120_414 => '\mathsfbfit{i} ',                                    # 1d65e
    120_415 => '\mathsfbfit{j} ',                                    # 1d65f
    120_416 => '\mathsfbfit{k} ',                                    # 1d660
    120_417 => '\mathsfbfit{l} ',                                    # 1d661
    120_418 => '\mathsfbfit{m} ',                                    # 1d662
    120_419 => '\mathsfbfit{n} ',                                    # 1d663
    120_420 => '\mathsfbfit{o} ',                                    # 1d664
    120_421 => '\mathsfbfit{p} ',                                    # 1d665
    120_422 => '\mathsfbfit{q} ',                                    # 1d666
    120_423 => '\mathsfbfit{r} ',                                    # 1d667
    120_424 => '\mathsfbfit{s} ',                                    # 1d668
    120_425 => '\mathsfbfit{t} ',                                    # 1d669
    120_426 => '\mathsfbfit{u} ',                                    # 1d66a
    120_427 => '\mathsfbfit{v} ',                                    # 1d66b
    120_428 => '\mathsfbfit{w} ',                                    # 1d66c
    120_429 => '\mathsfbfit{x} ',                                    # 1d66d
    120_430 => '\mathsfbfit{y} ',                                    # 1d66e
    120_431 => '\mathsfbfit{z} ',                                    # 1d66f
    120_432 => '\mathtt{A} ',                                        # 1d670
    120_433 => '\mathtt{B} ',                                        # 1d671
    120_434 => '\mathtt{C} ',                                        # 1d672
    120_435 => '\mathtt{D} ',                                        # 1d673
    120_436 => '\mathtt{E} ',                                        # 1d674
    120_437 => '\mathtt{F} ',                                        # 1d675
    120_438 => '\mathtt{G} ',                                        # 1d676
    120_439 => '\mathtt{H} ',                                        # 1d677
    120_440 => '\mathtt{I} ',                                        # 1d678
    120_441 => '\mathtt{J} ',                                        # 1d679
    120_442 => '\mathtt{K} ',                                        # 1d67a
    120_443 => '\mathtt{L} ',                                        # 1d67b
    120_444 => '\mathtt{M} ',                                        # 1d67c
    120_445 => '\mathtt{N} ',                                        # 1d67d
    120_446 => '\mathtt{O} ',                                        # 1d67e
    120_447 => '\mathtt{P} ',                                        # 1d67f
    120_448 => '\mathtt{Q} ',                                        # 1d680
    120_449 => '\mathtt{R} ',                                        # 1d681
    120_450 => '\mathtt{S} ',                                        # 1d682
    120_451 => '\mathtt{T} ',                                        # 1d683
    120_452 => '\mathtt{U} ',                                        # 1d684
    120_453 => '\mathtt{V} ',                                        # 1d685
    120_454 => '\mathtt{W} ',                                        # 1d686
    120_455 => '\mathtt{X} ',                                        # 1d687
    120_456 => '\mathtt{Y} ',                                        # 1d688
    120_457 => '\mathtt{Z} ',                                        # 1d689
    120_458 => '\mathtt{a} ',                                        # 1d68a
    120_459 => '\mathtt{b} ',                                        # 1d68b
    120_460 => '\mathtt{c} ',                                        # 1d68c
    120_461 => '\mathtt{d} ',                                        # 1d68d
    120_462 => '\mathtt{e} ',                                        # 1d68e
    120_463 => '\mathtt{f} ',                                        # 1d68f
    120_464 => '\mathtt{g} ',                                        # 1d690
    120_465 => '\mathtt{h} ',                                        # 1d691
    120_466 => '\mathtt{i} ',                                        # 1d692
    120_467 => '\mathtt{j} ',                                        # 1d693
    120_468 => '\mathtt{k} ',                                        # 1d694
    120_469 => '\mathtt{l} ',                                        # 1d695
    120_470 => '\mathtt{m} ',                                        # 1d696
    120_471 => '\mathtt{n} ',                                        # 1d697
    120_472 => '\mathtt{o} ',                                        # 1d698
    120_473 => '\mathtt{p} ',                                        # 1d699
    120_474 => '\mathtt{q} ',                                        # 1d69a
    120_475 => '\mathtt{r} ',                                        # 1d69b
    120_476 => '\mathtt{s} ',                                        # 1d69c
    120_477 => '\mathtt{t} ',                                        # 1d69d
    120_478 => '\mathtt{u} ',                                        # 1d69e
    120_479 => '\mathtt{v} ',                                        # 1d69f
    120_480 => '\mathtt{w} ',                                        # 1d6a0
    120_481 => '\mathtt{x} ',                                        # 1d6a1
    120_482 => '\mathtt{y} ',                                        # 1d6a2
    120_483 => '\mathtt{z} ',                                        # 1d6a3
    120_484 => '\imath ',                                            # 1d6a4
    120_485 => '\jmath ',                                            # 1d6a5
    120_490 => '\mathbf{\Gamma} ',                                   # 1d6aa
    120_491 => '\mathbf{\Delta} ',                                   # 1d6ab
    120_495 => '\mathbf{\Theta} ',                                   # 1d6af
    120_498 => '\mathbf{\Lambda} ',                                  # 1d6b2
    120_501 => '\mathbf{\Xi} ',                                      # 1d6b5
    120_503 => '\mathbf{\Pi} ',                                      # 1d6b7
    120_506 => '\mathbf{\Sigma} ',                                   # 1d6ba
    120_508 => '\mathbf{\Upsilon} ',                                 # 1d6bc
    120_509 => '\mathbf{\Phi} ',                                     # 1d6bd
    120_511 => '\mathbf{\Psi} ',                                     # 1d6bf
    120_512 => '\mathbf{\Omega} ',                                   # 1d6c0
    120_514 => '\mathbf{\alpha} ',                                   # 1d6c2
    120_515 => '\mathbf{\beta} ',                                    # 1d6c3
    120_516 => '\mathbf{\gamma} ',                                   # 1d6c4
    120_517 => '\mathbf{\delta} ',                                   # 1d6c5
    120_518 => '\mathbf{\varepsilon} ',                              # 1d6c6
    120_519 => '\mathbf{\zeta} ',                                    # 1d6c7
    120_520 => '\mathbf{\eta} ',                                     # 1d6c8
    120_521 => '\mathbf{\theta} ',                                   # 1d6c9
    120_522 => '\mathbf{\iota} ',                                    # 1d6ca
    120_523 => '\mathbf{\kappa} ',                                   # 1d6cb
    120_524 => '\mathbf{\lambda} ',                                  # 1d6cc
    120_525 => '\mathbf{\mu} ',                                      # 1d6cd
    120_526 => '\mathbf{\nu} ',                                      # 1d6ce
    120_527 => '\mathbf{\xi} ',                                      # 1d6cf
    120_529 => '\mathbf{\pi} ',                                      # 1d6d1
    120_530 => '\mathbf{\rho} ',                                     # 1d6d2
    120_531 => '\mathbf{\varsigma} ',                                # 1d6d3
    120_532 => '\mathbf{\sigma} ',                                   # 1d6d4
    120_533 => '\mathbf{\tau} ',                                     # 1d6d5
    120_534 => '\mathbf{\upsilon} ',                                 # 1d6d6
    120_535 => '\mathbf{\varphi} ',                                  # 1d6d7
    120_536 => '\mathbf{\chi} ',                                     # 1d6d8
    120_537 => '\mathbf{\psi} ',                                     # 1d6d9
    120_538 => '\mathbf{\omega} ',                                   # 1d6da
    120_540 => '\mathbf{\epsilon} ',                                 # 1d6dc
    120_541 => '\mathbf{\vartheta} ',                                # 1d6dd
    120_543 => '\mathbf{\phi} ',                                     # 1d6df
    120_544 => '\mathbf{\varrho} ',                                  # 1d6e0
    120_545 => '\mathbf{\varpi} ',                                   # 1d6e1
    120_548 => '\Gamma ',                                            # 1d6e4
    120_549 => '\Delta ',                                            # 1d6e5
    120_553 => '\Theta ',                                            # 1d6e9
    120_556 => '\Lambda ',                                           # 1d6ec
    120_559 => '\Xi ',                                               # 1d6ef
    120_561 => '\Pi ',                                               # 1d6f1
    120_564 => '\Sigma ',                                            # 1d6f4
    120_566 => '\Upsilon ',                                          # 1d6f6
    120_567 => '\Phi ',                                              # 1d6f7
    120_569 => '\Psi ',                                              # 1d6f9
    120_570 => '\Omega ',                                            # 1d6fa
    120_572 => '\alpha ',                                            # 1d6fc
    120_573 => '\beta ',                                             # 1d6fd
    120_574 => '\gamma ',                                            # 1d6fe
    120_575 => '\delta ',                                            # 1d6ff
    120_576 => '\varepsilon ',                                       # 1d700
    120_577 => '\zeta ',                                             # 1d701
    120_578 => '\eta ',                                              # 1d702
    120_579 => '\theta ',                                            # 1d703
    120_580 => '\iota ',                                             # 1d704
    120_581 => '\kappa ',                                            # 1d705
    120_582 => '\lambda ',                                           # 1d706
    120_583 => '\mu ',                                               # 1d707
    120_584 => '\nu ',                                               # 1d708
    120_585 => '\xi ',                                               # 1d709
    120_587 => '\pi ',                                               # 1d70b
    120_588 => '\rho ',                                              # 1d70c
    120_589 => '\varsigma ',                                         # 1d70d
    120_590 => '\sigma ',                                            # 1d70e
    120_591 => '\tau ',                                              # 1d70f
    120_592 => '\upsilon ',                                          # 1d710
    120_593 => '\varphi ',                                           # 1d711
    120_594 => '\chi ',                                              # 1d712
    120_595 => '\psi ',                                              # 1d713
    120_596 => '\omega ',                                            # 1d714
    120_597 => '\partial ',                                          # 1d715
    120_598 => '\epsilon ',                                          # 1d716
    120_599 => '\vartheta ',                                         # 1d717
    120_600 => '\varkappa ',                                         # 1d718
    120_601 => '\phi ',                                              # 1d719
    120_602 => '\varrho ',                                           # 1d71a
    120_603 => '\varpi ',                                            # 1d71b
    120_606 => '\mathbfit{\Gamma} ',                                 # 1d71e
    120_607 => '\mathbfit{\Delta} ',                                 # 1d71f
    120_611 => '\mathbfit{\Theta} ',                                 # 1d723
    120_614 => '\mathbfit{\Lambda} ',                                # 1d726
    120_617 => '\mathbfit{\Xi} ',                                    # 1d729
    120_619 => '\mathbfit{\Pi} ',                                    # 1d72b
    120_622 => '\mathbfit{\Sigma} ',                                 # 1d72e
    120_624 => '\mathbfit{\Upsilon} ',                               # 1d730
    120_625 => '\mathbfit{\Phi} ',                                   # 1d731
    120_627 => '\mathbfit{\Psi} ',                                   # 1d733
    120_628 => '\mathbfit{\Omega} ',                                 # 1d734
    120_630 => '\mathbfit{\alpha} ',                                 # 1d736
    120_631 => '\mathbfit{\beta} ',                                  # 1d737
    120_632 => '\mathbfit{\gamma} ',                                 # 1d738
    120_633 => '\mathbfit{\delta} ',                                 # 1d739
    120_634 => '\mathbfit{\varepsilon} ',                            # 1d73a
    120_635 => '\mathbfit{\zeta} ',                                  # 1d73b
    120_636 => '\mathbfit{\eta} ',                                   # 1d73c
    120_637 => '\mathbfit{\theta} ',                                 # 1d73d
    120_638 => '\mathbfit{\iota} ',                                  # 1d73e
    120_639 => '\mathbfit{\kappa} ',                                 # 1d73f
    120_640 => '\mathbfit{\lambda} ',                                # 1d740
    120_641 => '\mathbfit{\mu} ',                                    # 1d741
    120_642 => '\mathbfit{\nu} ',                                    # 1d742
    120_643 => '\mathbfit{\xi} ',                                    # 1d743
    120_645 => '\mathbfit{\pi} ',                                    # 1d745
    120_646 => '\mathbfit{\rho} ',                                   # 1d746
    120_647 => '\mathbfit{\varsigma} ',                              # 1d747
    120_648 => '\mathbfit{\sigma} ',                                 # 1d748
    120_649 => '\mathbfit{\tau} ',                                   # 1d749
    120_650 => '\mathbfit{\upsilon} ',                               # 1d74a
    120_651 => '\mathbfit{\varphi} ',                                # 1d74b
    120_652 => '\mathbfit{\chi} ',                                   # 1d74c
    120_653 => '\mathbfit{\psi} ',                                   # 1d74d
    120_654 => '\mathbfit{\omega} ',                                 # 1d74e
    120_656 => '\mathbfit{\epsilon} ',                               # 1d750
    120_657 => '\mathbfit{\vartheta} ',                              # 1d751
    120_659 => '\mathbfit{\phi} ',                                   # 1d753
    120_660 => '\mathbfit{\varrho} ',                                # 1d754
    120_661 => '\mathbfit{\varpi} ',                                 # 1d755
    120_664 => '\mathsfbf{\Gamma} ',                                 # 1d758
    120_665 => '\mathsfbf{\Delta} ',                                 # 1d759
    120_669 => '\mathsfbf{\Theta} ',                                 # 1d75d
    120_672 => '\mathsfbf{\Lambda} ',                                # 1d760
    120_675 => '\mathsfbf{\Xi} ',                                    # 1d763
    120_677 => '\mathsfbf{\Pi} ',                                    # 1d765
    120_680 => '\mathsfbf{\Sigma} ',                                 # 1d768
    120_682 => '\mathsfbf{\Upsilon} ',                               # 1d76a
    120_683 => '\mathsfbf{\Phi} ',                                   # 1d76b
    120_685 => '\mathsfbf{\Psi} ',                                   # 1d76d
    120_686 => '\mathsfbf{\Omega} ',                                 # 1d76e
    120_688 => '\mathsfbf{\alpha} ',                                 # 1d770
    120_689 => '\mathsfbf{\beta} ',                                  # 1d771
    120_690 => '\mathsfbf{\gamma} ',                                 # 1d772
    120_691 => '\mathsfbf{\delta} ',                                 # 1d773
    120_692 => '\mathsfbf{\varepsilon} ',                            # 1d774
    120_693 => '\mathsfbf{\zeta} ',                                  # 1d775
    120_694 => '\mathsfbf{\eta} ',                                   # 1d776
    120_695 => '\mathsfbf{\theta} ',                                 # 1d777
    120_696 => '\mathsfbf{\iota} ',                                  # 1d778
    120_697 => '\mathsfbf{\kappa} ',                                 # 1d779
    120_698 => '\mathsfbf{\lambda} ',                                # 1d77a
    120_699 => '\mathsfbf{\mu} ',                                    # 1d77b
    120_700 => '\mathsfbf{\nu} ',                                    # 1d77c
    120_701 => '\mathsfbf{\xi} ',                                    # 1d77d
    120_703 => '\mathsfbf{\pi} ',                                    # 1d77f
    120_704 => '\mathsfbf{\rho} ',                                   # 1d780
    120_705 => '\mathsfbf{\varsigma} ',                              # 1d781
    120_706 => '\mathsfbf{\sigma} ',                                 # 1d782
    120_707 => '\mathsfbf{\tau} ',                                   # 1d783
    120_708 => '\mathsfbf{\upsilon} ',                               # 1d784
    120_709 => '\mathsfbf{\varphi} ',                                # 1d785
    120_710 => '\mathsfbf{\chi} ',                                   # 1d786
    120_711 => '\mathsfbf{\psi} ',                                   # 1d787
    120_712 => '\mathsfbf{\omega} ',                                 # 1d788
    120_714 => '\mathsfbf{\epsilon} ',                               # 1d78a
    120_715 => '\mathsfbf{\vartheta} ',                              # 1d78b
    120_717 => '\mathsfbf{\phi} ',                                   # 1d78d
    120_718 => '\mathsfbf{\varrho} ',                                # 1d78e
    120_719 => '\mathsfbf{\varpi} ',                                 # 1d78f
    120_722 => '\mathsfbfit{\Gamma} ',                               # 1d792
    120_723 => '\mathsfbfit{\Delta} ',                               # 1d793
    120_727 => '\mathsfbfit{\Theta} ',                               # 1d797
    120_730 => '\mathsfbfit{\Lambda} ',                              # 1d79a
    120_733 => '\mathsfbfit{\Xi} ',                                  # 1d79d
    120_735 => '\mathsfbfit{\Pi} ',                                  # 1d79f
    120_738 => '\mathsfbfit{\Sigma} ',                               # 1d7a2
    120_740 => '\mathsfbfit{\Upsilon} ',                             # 1d7a4
    120_741 => '\mathsfbfit{\Phi} ',                                 # 1d7a5
    120_743 => '\mathsfbfit{\Psi} ',                                 # 1d7a7
    120_744 => '\mathsfbfit{\Omega} ',                               # 1d7a8
    120_746 => '\mathsfbfit{\alpha} ',                               # 1d7aa
    120_747 => '\mathsfbfit{\beta} ',                                # 1d7ab
    120_748 => '\mathsfbfit{\gamma} ',                               # 1d7ac
    120_749 => '\mathsfbfit{\delta} ',                               # 1d7ad
    120_750 => '\mathsfbfit{\varepsilon} ',                          # 1d7ae
    120_751 => '\mathsfbfit{\zeta} ',                                # 1d7af
    120_752 => '\mathsfbfit{\eta} ',                                 # 1d7b0
    120_753 => '\mathsfbfit{\theta} ',                               # 1d7b1
    120_754 => '\mathsfbfit{\iota} ',                                # 1d7b2
    120_755 => '\mathsfbfit{\kappa} ',                               # 1d7b3
    120_756 => '\mathsfbfit{\lambda} ',                              # 1d7b4
    120_757 => '\mathsfbfit{\mu} ',                                  # 1d7b5
    120_758 => '\mathsfbfit{\nu} ',                                  # 1d7b6
    120_759 => '\mathsfbfit{\xi} ',                                  # 1d7b7
    120_761 => '\mathsfbfit{\pi} ',                                  # 1d7b9
    120_762 => '\mathsfbfit{\rho} ',                                 # 1d7ba
    120_763 => '\mathsfbfit{\varsigma} ',                            # 1d7bb
    120_764 => '\mathsfbfit{\sigma} ',                               # 1d7bc
    120_765 => '\mathsfbfit{\tau} ',                                 # 1d7bd
    120_766 => '\mathsfbfit{\upsilon} ',                             # 1d7be
    120_767 => '\mathsfbfit{\varphi} ',                              # 1d7bf
    120_768 => '\mathsfbfit{\chi} ',                                 # 1d7c0
    120_769 => '\mathsfbfit{\psi} ',                                 # 1d7c1
    120_770 => '\mathsfbfit{\omega} ',                               # 1d7c2
    120_772 => '\mathsfbfit{\epsilon} ',                             # 1d7c4
    120_773 => '\mathsfbfit{\vartheta} ',                            # 1d7c5
    120_775 => '\mathsfbfit{\phi} ',                                 # 1d7c7
    120_776 => '\mathsfbfit{\varrho} ',                              # 1d7c8
    120_777 => '\mathsfbfit{\varpi} ',                               # 1d7c9
    120_782 => '\mathbf{0} ',                                        # 1d7ce
    120_783 => '\mathbf{1} ',                                        # 1d7cf
    120_784 => '\mathbf{2} ',                                        # 1d7d0
    120_785 => '\mathbf{3} ',                                        # 1d7d1
    120_786 => '\mathbf{4} ',                                        # 1d7d2
    120_787 => '\mathbf{5} ',                                        # 1d7d3
    120_788 => '\mathbf{6} ',                                        # 1d7d4
    120_789 => '\mathbf{7} ',                                        # 1d7d5
    120_790 => '\mathbf{8} ',                                        # 1d7d6
    120_791 => '\mathbf{9} ',                                        # 1d7d7
    120_792 => '\mathbb{0} ',                                        # 1d7d8
    120_793 => '\mathbb{1} ',                                        # 1d7d9
    120_794 => '\mathbb{2} ',                                        # 1d7da
    120_795 => '\mathbb{3} ',                                        # 1d7db
    120_796 => '\mathbb{4} ',                                        # 1d7dc
    120_797 => '\mathbb{5} ',                                        # 1d7dd
    120_798 => '\mathbb{6} ',                                        # 1d7de
    120_799 => '\mathbb{7} ',                                        # 1d7df
    120_800 => '\mathbb{8} ',                                        # 1d7e0
    120_801 => '\mathbb{9} ',                                        # 1d7e1
    120_802 => '\mathsf{0} ',                                        # 1d7e2
    120_803 => '\mathsf{1} ',                                        # 1d7e3
    120_804 => '\mathsf{2} ',                                        # 1d7e4
    120_805 => '\mathsf{3} ',                                        # 1d7e5
    120_806 => '\mathsf{4} ',                                        # 1d7e6
    120_807 => '\mathsf{5} ',                                        # 1d7e7
    120_808 => '\mathsf{6} ',                                        # 1d7e8
    120_809 => '\mathsf{7} ',                                        # 1d7e9
    120_810 => '\mathsf{8} ',                                        # 1d7ea
    120_811 => '\mathsf{9} ',                                        # 1d7eb
    120_812 => '\mathsfbf{0} ',                                      # 1d7ec
    120_813 => '\mathsfbf{1} ',                                      # 1d7ed
    120_814 => '\mathsfbf{2} ',                                      # 1d7ee
    120_815 => '\mathsfbf{3} ',                                      # 1d7ef
    120_816 => '\mathsfbf{4} ',                                      # 1d7f0
    120_817 => '\mathsfbf{5} ',                                      # 1d7f1
    120_818 => '\mathsfbf{6} ',                                      # 1d7f2
    120_819 => '\mathsfbf{7} ',                                      # 1d7f3
    120_820 => '\mathsfbf{8} ',                                      # 1d7f4
    120_821 => '\mathsfbf{9} ',                                      # 1d7f5
    120_822 => '\mathtt{0} ',                                        # 1d7f6
    120_823 => '\mathtt{1} ',                                        # 1d7f7
    120_824 => '\mathtt{2} ',                                        # 1d7f8
    120_825 => '\mathtt{3} ',                                        # 1d7f9
    120_826 => '\mathtt{4} ',                                        # 1d7fa
    120_827 => '\mathtt{5} ',                                        # 1d7fb
    120_828 => '\mathtt{6} ',                                        # 1d7fc
    120_829 => '\mathtt{7} ',                                        # 1d7fd
    120_830 => '\mathtt{8} ',                                        # 1d7fe
    120_831 => '\mathtt{9} ',                                        # 1d7ff
    128_276 => '\bell '                                              # 1f514
  }.freeze
end
